@@ -2,17 +2,11 @@
 # type / size strict-ness
 
 test_that("size of each `.f` result must be 1", {
-  expect_error(
-    slide_vec(1:2, ~c(.x, 1)),
-    "In iteration 1, the result of `.f` had size 2, not 1"
-  )
+  expect_snapshot(error = TRUE, slide_vec(1:2, ~c(.x, 1)))
 })
 
 test_that("size of each `.f` result must be 1", {
-  expect_error(
-    slide_dbl(1:2, ~c(.x, 1)),
-    "In iteration 1, the result of `.f` had size 2, not 1"
-  )
+  expect_snapshot(error = TRUE, slide_dbl(1:2, ~c(.x, 1)))
 })
 
 test_that("inner type is allowed to be different", {
@@ -23,17 +17,21 @@ test_that("inner type is allowed to be different", {
 })
 
 test_that("inner type can be restricted with list_of", {
-  expect_error(
-    slide_vec(1:2, ~if (.x == 1L) {list_of(1)} else {list_of("hi")}, .ptype = list_of(.ptype = double())),
-    class = "vctrs_error_incompatible_type"
-  )
+  expect_snapshot({
+    (expect_error(
+      slide_vec(1:2, ~if (.x == 1L) {list_of(1)} else {list_of("hi")}, .ptype = list_of(.ptype = double())),
+      class = "vctrs_error_incompatible_type"
+    ))
+  })
 })
 
 test_that("inner type can be restricted", {
-  expect_error(
-    slide_dbl(1:2, ~if (.x == 1L) {1} else {"x"}),
-    class = "vctrs_error_incompatible_type"
-  )
+  expect_snapshot({
+    (expect_error(
+      slide_dbl(1:2, ~if (.x == 1L) {1} else {"x"}),
+      class = "vctrs_error_incompatible_type"
+    ))
+  })
 })
 
 # ------------------------------------------------------------------------------
@@ -42,7 +40,9 @@ test_that("inner type can be restricted", {
 test_that(".ptype is respected", {
   expect_equal(slide_vec(1, ~.x), 1)
   expect_equal(slide_vec(1, ~.x, .ptype = int()), 1L)
-  expect_error(slide_vec(1, ~.x + .5, .ptype = integer()), class = "vctrs_error_cast_lossy")
+  expect_snapshot({
+    (expect_error(slide_vec(1, ~.x + .5, .ptype = integer()), class = "vctrs_error_cast_lossy"))
+  })
 })
 
 test_that("`.ptype = NULL` results in 'guessed' .ptype", {
@@ -53,17 +53,18 @@ test_that("`.ptype = NULL` results in 'guessed' .ptype", {
 })
 
 test_that("`.ptype = NULL` fails if no common type is found", {
-  expect_error(
-    slide_vec(1:2, ~ifelse(.x == 1L, "hello", 1), .ptype = NULL),
-    class = "vctrs_error_incompatible_type"
-  )
+  expect_snapshot({
+    (expect_error(
+      slide_vec(1:2, ~ifelse(.x == 1L, "hello", 1), .ptype = NULL),
+      class = "vctrs_error_incompatible_type"
+    ))
+  })
 })
 
 test_that("`.ptype = NULL` validates that element lengths are 1", {
-  expect_error(
-    slide_vec(1:2, ~if(.x == 1L) {1:2} else {1}, .ptype = NULL),
-    "In iteration 1, the result of `.f` had size 2, not 1."
-  )
+  expect_snapshot(error = TRUE, {
+    slide_vec(1:2, ~if(.x == 1L) {1:2} else {1}, .ptype = NULL)
+  })
 })
 
 test_that("`.ptype = NULL` returns `NULL` with size 0 `.x`", {
@@ -76,7 +77,7 @@ test_that("`.ptype = NULL` is size stable (#78)", {
 })
 
 test_that(".ptypes with a vec_proxy() are restored to original type", {
-  expect_is(
+  expect_s3_class(
     slide_vec(Sys.Date() + 1:5, ~.x, .ptype = as.POSIXlt(Sys.Date())),
     "POSIXlt"
   )
@@ -202,7 +203,9 @@ test_that("slide_chr() works", {
 })
 
 test_that("slide_chr() cannot coerce", {
-  expect_error(slide_chr(1, ~.x), class = "vctrs_error_incompatible_type")
+  expect_snapshot({
+    (expect_error(slide_chr(1, ~.x), class = "vctrs_error_incompatible_type"))
+  })
 })
 
 test_that("slide_lgl() works", {
@@ -217,27 +220,34 @@ test_that("slide_lgl() can coerce", {
 # data frame suffix tests
 
 test_that("slide_dfr() works", {
-  expect_equal(
-    slide_dfr(1:2, ~.x, .before = 1),
-    data.frame(...1 = c(1, 1), ...2 = c(NA, 2))
-  )
-
-  x <- 1:2
-  expect_equal(
-    slide_dfr(x, ~data.frame(x = .x), .before = 1),
-    data.frame(x = c(1, 1, 2))
+  expect_identical(
+    slide_dfr(
+      1:2,
+      ~new_data_frame(list(x = list(.x))),
+      .before = 1
+    ),
+    data_frame(
+      x = list(1L, 1:2)
+    )
   )
 })
 
 test_that("slide_dfc() works", {
-  expect_equal(
-    slide_dfc(1:2, ~.x, .before = 1),
-    data.frame(...1 = c(1, 1), ...2 = c(1, 2))
-  )
-
   x <- 1:2
-  expect_equal(
-    slide_dfc(x, ~data.frame(x = .x), .before = 1),
-    data.frame(x...1 = c(1, 1), x...2 = c(1, 2))
+
+  fn <- function(x) {
+    if (length(x) == 1) {
+      data.frame(x1 = x)
+    } else {
+      data.frame(x2 = x)
+    }
+  }
+
+  expect_identical(
+    slide_dfc(1:2, fn, .before = 1),
+    data.frame(
+      x1 = c(1L, 1L),
+      x2 = 1:2
+    )
   )
 })
